@@ -28,17 +28,18 @@
 
 #include <eel/eel-art-extensions.h>
 #include <gdk-pixbuf/gdk-pixbuf.h>
-#include <gdk/gdk.h>
-#include <gio/gio.h>
+#include <gdk/gdkdrawable.h>
+#include <gdk/gdkrgb.h>
+#include <libgnomevfs/gnome-vfs-result.h>
 
 #define EEL_STANDARD_ALPHA_THRESHHOLD 128
 #define EEL_OPACITY_FULLY_TRANSPARENT 0
 #define EEL_OPACITY_FULLY_OPAQUE      255
 
-extern const EelIRect eel_gdk_pixbuf_whole_pixbuf;
+extern const ArtIRect eel_gdk_pixbuf_whole_pixbuf;
 
 typedef struct EelPixbufLoadHandle EelPixbufLoadHandle;
-typedef void (* EelPixbufLoadCallback) (GError         *error,
+typedef void (* EelPixbufLoadCallback) (GnomeVFSResult  error,
 					GdkPixbuf      *pixbuf,
 					gpointer        callback_data);
 
@@ -50,9 +51,6 @@ void                 eel_gdk_pixbuf_list_free                 (GList
 
 /* Loading a GdkPixbuf with a URI. */
 GdkPixbuf *          eel_gdk_pixbuf_load                      (const char            *uri);
-GdkPixbuf *          eel_gdk_pixbuf_load_from_stream          (GInputStream          *stream);
-GdkPixbuf *          eel_gdk_pixbuf_load_from_stream_at_size  (GInputStream          *stream,
-							       int                    size);
 
 
 /* Same thing async. */
@@ -86,7 +84,7 @@ double              eel_gdk_scale_to_min_factor               (int
 /* return average color values for each component (argb) */
 guint32              eel_gdk_pixbuf_average_value             (GdkPixbuf             *pixbuf);
 void                 eel_gdk_pixbuf_fill_rectangle_with_color (GdkPixbuf             *pixbuf,
-							       EelIRect               area,
+							       ArtIRect               area,
 							       guint32                color);
 
 
@@ -103,7 +101,7 @@ void                 eel_gdk_pixbuf_draw_to_drawable          (const GdkPixbuf
 							       GdkGC                 *gc,
 							       int                    source_x,
 							       int                    source_y,
-							       EelIRect               destination_area,
+							       ArtIRect               destination_area,
 							       GdkRgbDither           dither,
 							       GdkPixbufAlphaMode     alpha_compositing_mode,
 							       int                    alpha_threshold);
@@ -113,7 +111,7 @@ void                 eel_gdk_pixbuf_draw_to_pixbuf            (const GdkPixbuf
 							       GdkPixbuf             *destination_pixbuf,
 							       int                    source_x,
 							       int                    source_y,
-							       EelIRect               destination_area);
+							       ArtIRect               destination_area);
 
 
 /* Composite one pixbuf over another with the given opacity */
@@ -121,19 +119,43 @@ void                 eel_gdk_pixbuf_draw_to_pixbuf_alpha      (const GdkPixbuf
 							       GdkPixbuf             *destination_pixbuf,
 							       int                    source_x,
 							       int                    source_y,
-							       EelIRect               destination_area,
+							       ArtIRect               destination_area,
 							       int                    opacity,
 							       GdkInterpType          interpolation_mode);
 
 
+/* Fill an area of a pixbuf with a tile. */
+void                 eel_gdk_pixbuf_draw_to_pixbuf_tiled      (const GdkPixbuf       *pixbuf,
+							       GdkPixbuf             *destination_pixbuf,
+							       ArtIRect               destination_area,
+							       int                    tile_width,
+							       int                    tile_height,
+							       int                    tile_origin_x,
+							       int                    tile_origin_y,
+							       int                    opacity,
+							       GdkInterpType          interpolation_mode);
+
+/* Fill an area of a drawable with a tile. */
+void                 eel_gdk_pixbuf_draw_to_drawable_tiled    (const GdkPixbuf       *pixbuf,
+							       GdkDrawable           *drawable,
+							       GdkGC                 *gc,
+							       ArtIRect               destination_area,
+							       int                    tile_width,
+							       int                    tile_height,
+							       int                    tile_origin_x,
+							       int                    tile_origin_y,
+							       GdkRgbDither           dither,
+							       GdkPixbufAlphaMode     alpha_compositing_mode,
+							       int                    alpha_threshold);
+
 /* Create a pixbuf from a sub area of another pixbuf */
 GdkPixbuf *          eel_gdk_pixbuf_new_from_pixbuf_sub_area  (GdkPixbuf             *pixbuf,
-							       EelIRect               area);
+							       ArtIRect               area);
 /* Create a pixbuf from an existing buffer. */
 GdkPixbuf *          eel_gdk_pixbuf_new_from_existing_buffer  (guchar                *buffer,
 							       int                    buffer_rowstride,
 							       gboolean               buffer_has_alpha,
-							       EelIRect               area);
+							       ArtIRect               area);
 
 /* Determine whether a pixbuf is valid or not */
 gboolean             eel_gdk_pixbuf_is_valid                  (const GdkPixbuf       *pixbuf);
@@ -142,10 +164,22 @@ gboolean             eel_gdk_pixbuf_is_valid                  (const GdkPixbuf
 EelDimensions        eel_gdk_pixbuf_get_dimensions            (const GdkPixbuf       *pixbuf);
 
 /* Return the intersection of the pixbuf with the given rectangle. */
-EelIRect             eel_gdk_pixbuf_intersect                 (const GdkPixbuf       *pixbuf,
+ArtIRect             eel_gdk_pixbuf_intersect                 (const GdkPixbuf       *pixbuf,
 							       int                    pixbuf_x,
 							       int                    pixbuf_y,
-							       EelIRect               rectangle);
+							       ArtIRect               rectangle);
+
+/* Text drawing. */
+void                 eel_gdk_pixbuf_draw_layout               (GdkPixbuf             *pixbuf,
+							       int                    x,
+							       int                    y,
+							       guint32                color,
+							       PangoLayout           *layout);
+
+void                 eel_gdk_pixbuf_draw_layout_clipped       (GdkPixbuf             *pixbuf,
+							       ArtIRect               region,
+							       guint32                color,
+							       PangoLayout           *layout);
 
 /* Scales large pixbufs down fast */
 GdkPixbuf *          eel_gdk_pixbuf_scale_down                (GdkPixbuf *pixbuf,
