@@ -5,16 +5,16 @@
    Copyright (C) 1999, 2000 Eazel, Inc.
   
    This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public License as
+   modify it under the terms of the GNU Library General Public License as
    published by the Free Software Foundation; either version 2 of the
    License, or (at your option) any later version.
   
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   General Public License for more details.
+   Library General Public License for more details.
   
-   You should have received a copy of the GNU General Public
+   You should have received a copy of the GNU Library General Public
    License along with this program; if not, write to the
    Free Software Foundation, Inc., 59 Temple Place - Suite 330,
    Boston, MA 02111-1307, USA.
@@ -283,6 +283,17 @@ eel_string_list_insert (EelStringList *string_list,
 					       g_strdup (string));
 }
 
+void
+eel_string_list_prepend (EelStringList *string_list,
+			 const char *string)
+{
+	g_return_if_fail (string_list != NULL);
+	g_return_if_fail (string != NULL);
+
+	string_list->strings = g_slist_prepend (string_list->strings,
+						g_strdup (string));
+}
+
 void
 eel_string_list_insert_string_list (EelStringList *string_list,
 				    const EelStringList *other_string_list)
@@ -300,6 +311,26 @@ eel_string_list_insert_string_list (EelStringList *string_list,
 	}
 }
 
+G_CONST_RETURN char *
+eel_string_list_peek_nth (const EelStringList *string_list,
+			  guint n)
+{
+	const char *nth_string;
+	
+	g_return_val_if_fail (string_list != NULL, NULL);
+	
+	if (n  < g_slist_length (string_list->strings)) {
+		nth_string = g_slist_nth_data (string_list->strings, n);
+		g_return_val_if_fail (nth_string != NULL, NULL);
+		
+		return nth_string;
+	} else if (!suppress_out_of_bounds_warning) {
+		g_warning ("eel_string_list_nth (n = %d) is out of bounds.", n);
+	}
+	
+	return NULL;
+}
+
 char *
 eel_string_list_nth (const EelStringList *string_list,
 		     guint n)
@@ -458,7 +489,7 @@ eel_string_list_find_by_function (const EelStringList *string_list,
 		return NULL;
 	}
 
-	g_return_val_if_fail (test_function != NULL, FALSE);
+	g_return_val_if_fail (test_function != NULL, NULL);
 	
 	for (node = string_list->strings; node; node = node->next) {
 		if ((* test_function) (string_list, node->data, callback_data)) {
@@ -535,21 +566,49 @@ eel_string_list_equals (const EelStringList *a,
 GSList *
 eel_string_list_as_g_slist (const EelStringList *string_list)
 {
-	guint i;
 	GSList *gslist;
+	GSList *l;
 	
 	if (string_list == NULL) {
 		return NULL;
 	}
 
 	gslist = NULL;
-	for (i = 0; i < eel_string_list_get_length (string_list); i++) {
-		gslist = g_slist_append (gslist, eel_string_list_nth (string_list, i));
+	for (l = string_list->strings; l != NULL; l = l->next) {
+		gslist = g_slist_prepend (gslist, g_strdup (l->data));
 	}
+	gslist = g_slist_reverse (gslist);
 
 	return gslist;
 }
 
+/**
+ * eel_string_list_as_g_list:
+ *
+ * @string_list: A EelStringList
+ *
+ * Return value: A GList of strings that must deep free the result with
+ * eel_g_list_free_deep()
+ */
+GList *
+eel_string_list_as_g_list (const EelStringList *string_list)
+{
+	GList *glist;
+	GSList *l;
+	
+	if (string_list == NULL) {
+		return NULL;
+	}
+
+	glist = NULL;
+	for (l = string_list->strings; l != NULL; l = l->next) {
+		glist = g_list_prepend (glist, g_strdup (l->data));
+	}
+	glist = g_list_reverse (glist);
+
+	return glist;
+}
+
 /**
  * eel_string_list_get_index_for_string:
  *
@@ -785,8 +844,8 @@ eel_string_list_for_each (const EelStringList *string_list,
 }
 
 void
-eel_string_list_append (EelStringList *string_list,
-			const EelStringList *append_string_list)
+eel_string_list_append_string_list (EelStringList *string_list,
+				    const EelStringList *append_string_list)
 {
 	const GSList *node;
 
@@ -1052,8 +1111,6 @@ eel_self_check_string_list (void)
 	 */
 
 	{
-		EelStringList *fruits;
-
 		fruits = eel_string_list_new (TRUE);
 		
 		eel_string_list_insert (fruits, "orange");
